## AIS Python Components

This package contains the AIStore Python SDK, PyTorch integration, and Botocore patch. 
See the README files in each module for usage details:

- [SDK](https://github.com/NVIDIA/aistore/blob/main/python/aistore/sdk/README.md)
- [PyTorch](https://github.com/NVIDIA/aistore/blob/main/python/aistore/pytorch/README.md)
- [Botocore](https://github.com/NVIDIA/aistore/blob/main/python/aistore/botocore_patch/README.md)

## References

* [AIStore GitHub](https://github.com/NVIDIA/aistore)
* [Documentation](https://aistore.nvidia.com/docs)
* [AIStore pip package](https://pypi.org/project/aistore/)
* [KubeCon 2024 presentation](https://www.youtube.com/watch?v=N-d9cbROndg)

